%% Calculate Acoustic Potential Energy from Full FSI Ansys Analysis
% This script can be used to calculate the acoustic potential energy from
% conducting a full harmonic analysis, where the pressure at every node and
% every frequency has been exported.

%% Check existance of m.c.n.vol
% Before calculting the results, make sure that the modal data has already
% been processed, so that the volume associated with each node has been
% calculated and available in the matlab structure m.c.n.vol
if ~isfield(m.c.n,'vol')
    disp('Use the loadmodel.m script first to calculate the nodal volume');
    error('Use the Ansys modal coupling scripts first.');
end;


%% Load the exported Ansys results
% Load the real pressure at every node and every frequency.
% This could take a while
p_real=load('real_p.txt');
% Convert the data into an array
p_real=readansysarray(p_real);

%%%
% Load the imaginary pressure at every node and every frequency.
% This could take a while
p_imag=load('imag_p.txt');
% Convert the data into an array
p_imag=readansysarray(p_imag);

%%% 
% Put the real and imaginary pressure results into a single variable
% which has dimensions [nodes x frequencies]
pressure=p_real+1i*p_imag;
clear p_real
clear p_imag

%% Calculate the Acoustic Potential Energy
% The acoustic potential energy can be calculated as
%
% $$
% E_{p}({\omega}) = {\frac{1}{4 {\rho_0} c_{0}^{2}}}
% \sum_{n=1}^{N_{a}} p_{n}^{2}(\omega) V_{n}
% $$
% 
% where
%
% * $\omega$ is the circular frequency
% * $N_a$ is the number of nodes
% * $p_{n}(\omega)$ is the pressure at the nth node at circular 
% frequency $\omega$ 
% * $V_n$ is the volume associated with the nth node
% * $\rho_0$ is the density of the fluid
% * $c_0$ is the speed of sound of the fluid
%
%

nodal_volume=zeros(size(pressure,2),1);
for ii=1:length(m.c.n.num)
    nodal_volume(m.c.n.num(ii))=m.c.n.vol(ii);
end;


for ff=1:size(pressure,2)
    temp_ape(ff)=sum(abs(pressure(:,ff)).^2 .* nodal_volume);
end;

rho=m.c.dens;
c_speed_sound=m.c.c;

ansys_ape_long_way=1/(4*rho*c_speed_sound^2)*temp_ape;


 
