function B = bli(m,analysis)
% B(c,s) - Calculate the coupling coefficient between the acoustic modes 
%          and the structural modes.
% [B] = [ncavmodes,nstrmodes]
% Calculated as per Cazzolato thesis, Equation (2.24)

% c.p is a matrix of acoustic mode shapes (phi) = [ncavnodes,ncavmodes]
% s.p is a matrix of normal structural mode shapes (psi)= [nstrnodes,nstrmodes]
% s.n.area is the effective area of a structural node = [nstrnodes,1]
if nargin==1
    analysis='coupled';
end

% Defined by the following equation
% Bl,i = 1/S * INT ( PSI*PHI*dS ) 

switch analysis
    case 'coupled'
       nodearea=m.s.n.area;
       nstrmodes=length(m.s.f);
       psi=m.s.p;
       phi=m.c.p;
       vect=m.c.n.idx(m.s.n.num);

       B = ((nodearea*ones(1,nstrmodes).*psi).'*phi(vect,:)./sum(nodearea)).';

       % B = ((s.n.area*ones(1,length(s.freq)).*s.p).'*c.p(s.n.idx(s.n.num))./sum(s.n.area)).';
   case 'uncoupled'
       B = zeros(length(m.c.f),length(m.s.f))
   otherwise
       error('unknown case in b')
end
