function m=fahy_ansys(m,lcindex)

% Tries to implement Fahy's version of coupled acoustics.
%
% This version take the m structure that is calculated from the ANSYS modal
% results and the loadmodel script. It has been compared with the old
% script developed by Rick and Ben and it is about 30% faster.
%
% It was found that if the damping terms are removed, then it is calculated
% 5 times faster than the old way... there must be a way to include
% damping, but retain real matrices to get the best benefit.
%
% This version uses a different model for the damping
%
% Carl Howard 3 October 2003
%


if nargin~=2
    error('Insufficient input parameters. Read the help...');
end;    

% % parse out lcindex
if ischar(lcindex)
    names={};
    for ii=1:length(m.lc)
        names{ii}=m.lc{ii}.name;
    end
    [true,lcindex]=ismember(lcindex,names);
    if ~true
        error('load case name not in set');
    end
elseif lcindex<1 | lcindex>length(m.lc)
    error('load case index incorrect')
end



% frequency independant
strfreq     = m.s.f;
nstrmodes   = length(strfreq);
strloss     = m.lc{lcindex}.sl;
modalmass   = m.s.mm;
psinorm     = m.s.p;
pstrnode    = m.lc{lcindex}.sn;

cavfreq     = m.c.f;
ncavmodes   = length(cavfreq);
cavloss     = m.lc{lcindex}.cl;
modalvolume = m.c.mv;
phi         = m.c.p;
pcavnode    = m.lc{lcindex}.cn;

Bij         = m.bli;
densair     = m.c.dens;
speedair    = m.c.c;
surfacearea = sum(m.s.n.area);




% extract all the n=0 case into separate variables
% cavfreq_0       = cavfreq(1);       % if this isn't =0, then there is something wrong
% cavfreq         = cavfreq(2:ncavmodes);
% modalvolume_0   = modalvolume(1);
% modalvolume     = modalvolume(2:ncavmodes).';
% Bij_0           = Bij(1,:);
% Bij             = Bij(2:ncavmodes,:);
% ncavmodes       = ncavmodes-1;



C_11_temp   = diag((strfreq*2*pi).^2 .* modalmass);
C_12        = -surfacearea*Bij;
C_21        = C_12.';
C_22_temp1  = diag(modalvolume .* (2*pi*cavfreq).^2 / (densair*speedair.^2));
C_22_temp2  = diag(modalvolume / (densair*speedair.^2));


    

if isempty(m.lc{lcindex}.freq),
    error('You need to define the frequency vector using createloadcase first.');
end;

end_freq=m.lc{lcindex}.freq(length(m.lc{lcindex}.freq));

for freqindex=1:length(m.lc{lcindex}.freq);
	

	% frequency dependant
	freq=m.lc{lcindex}.freq(freqindex);

    omega = 2*pi*freq;

    
    fprintf('frequency %5.1f of %5.1f\n',freq,end_freq);
    
	if size(m.lc{lcindex}.sf,2)>1
        pstrforce = m.lc{lcindex}.sf(:,freqindex);
	else
        pstrforce = m.lc{lcindex}.sf;
	end
	if size(m.lc{lcindex}.cq,2)>1
        pcavq = m.lc{lcindex}.cq(:,freqindex);
	else
        pcavq = m.lc{lcindex}.cq;
	end

    if ~isempty(pstrnode),
        RHS_top = psinorm(m.s.n.idx(pstrnode),:).' * pstrforce;
    else
        RHS_top = zeros(nstrmodes,1);
    end;
    if ~isempty(pcavnode),
        RHS_bottom = phi(m.c.n.idx(pcavnode),:).' * pcavq;
    else
        RHS_bottom = zeros(ncavmodes,1);
    end;
    
    RHS     =   [   RHS_top         ;       ...
                    RHS_bottom./(omega.^2)      ];

    % This is the term for the structure
    %C_11    =   C_11_temp-diag(modalmass)*(omega.^2) +    ...
    %            diag(j*strloss*(strfreq*2*pi).^2 .* modalmass);
    C_11    =   C_11_temp-diag(modalmass)*(omega.^2);

    % This is the term for the acoustic cavity
    C_22    =   C_22_temp1/(omega.^2)-C_22_temp2;
    
    LHS     =   [   C_11        C_12.'      ;   ...
                    C_21.'      C_22        ];
                
    small_q = inv(LHS)*RHS;
    
    m.lc{lcindex}.sp(:,freqindex)=small_q(1:nstrmodes,:);
    
    m.lc{lcindex}.cp(:,freqindex) =small_q(nstrmodes+1:nstrmodes+ncavmodes,:);
    
end; % of the big frequency loop
    
disp('End of calculations')




