function m=createloadcase(m,name,freq,sn,sf,sl,cn,cq,cl)
% create load case in model m
%
% usage: m=createloadcase(m,name,freq,sn,sf,sl,cn,cq,cl)
%
% name = identifier of load case (unique)
% freq = frequencies of interest (nfreq x 1)
% sn   = vector of node numbers for structural loading (nstrnodes x 1) 
% sf   = vector of nodal forces (N) for structural loading (can be complex)
%        (nstrnodes x 1) for frequency independant loading
%        (nstrnodes x length(freq)) for frequency dependant loading
% sl   = structural loss factor ( can be scalar or 1 x nstrmodes)
% cn   = vector of node numbers for cavity loading (ncavnodes X 1)
% cf   = vector of nodal volume velocity (m^3/s) for cavity loading (can be complex)
%        (ncavnodes x 1) for frequency independant loading
%        (ncavnodes x length(lfreq)) for frequency dependant loading
% cl   = structural loss factor ( can be scalar or 1 x nstrmodes)

% reshape sn and cn in case not (nstrnode x 1)
sn=sn(:);
cn=cn(:);

% add loadcase field if it doesnt already exist
if ~isfield(m,'lc')
    m.lc={};
end

% check if loadcase name already exists
names={};
for ii=1:length(m.lc)
    names{ii}=m.lc{ii}.name;
end

if ismember(name,names)
    error('new loadcase has the same name as a previous loadcase');
end

% check if nodes referenced are in model
if ~isempty(sn)
    if sum(ismember(sn,m.s.n.num))~=length(sn)
        error('structural node numbers not referenced in model')
    end
end

if ~isempty(cn)
    if sum(ismember(cn,m.c.n.num))~=length(cn)
        error('cavity node numbers not referenced in model')
    end
end

% check if loads are the same length as nodes
if (length(sn)~=size(sf,1))
    error('number of structural forces and nodes not equal')
end

% check if loads are the same length as nodes
if (length(cn)~=size(cq,1))
    error('number of cavity volume velocities and nodes not equal')
end

% check if frequency dependant forces are correct
if size(sf,2)>1 & size(sf,2)~=length(freq)
    error('frequency dependent structual loading incorrect length')
end
if size(cq,2)>1 & size(cq,2)~=length(freq)
    error('frequency dependent cavity loading incorrect length')
end

lc.name=name;
lc.freq=freq;
lc.sn=sn;
lc.sf=sf;
lc.sl=sl;
lc.cn=cn;
lc.cq=cq;
lc.cl=cl;

m.lc{length(m.lc)+1}=lc;
