function plotmode(s,mode)
% Plot the mode as a coloured element plot
% Usage: 
%   To plot the acoustic mode shape:
%   m.c.pl=plotmodel(m.c); plotmode(m.c,mode_num);
%
%   To plot the structural mode shape:
%   m.s.pl=plotmodel(m.s); plotmode(m.s,mode_num);
%
% where:
%   mode_num:   mode number
%   m.c or m.s: structure array of the model after by using loadmodel.m
%
% when mode_num=0 the colour contours are not displayed.
%
% Notes:
% - if the figure window is closed, this function generate an error. 
%   Re-run according the Usage instructions.
%   

if nargin ~= 2
    error('2 input arguments required');
end

if mode > length(s.f)
    error('mode plot requested out of range')
end

if ~isfield(s,'pl')
    error('plotmode:fieldpldoesnotexist',   ...
        ['The field .pl does not exist in the structure array. \n', ...
        'Use this function as follows: \n',    ...
        'm.c.pl=plotmodel(m.c); plotmode(m.c,5); \n',   ...
        'or \n',    ...
        'm.s.pl=plotmodel(m.s); plotmode(m.s,5);']  );
end;


switch s.id
    case 'str'
        type='Structural';
    case 'cav'
        type='Cavity';
end

% Check that the figure is currently displayed
if ~ishandle(s.pl.f)
    error('plotmode:nofigureexists',    ...
        ['The figure number associated with the structure or cavity is not displayed. \n', ...
            'Re-run m.c.pl=plotmodel(m.c); plotmode(m.c,5); \n', ...
            'or \n',     ...
            'm.s.pl=plotmodel(m.s); plotmode(m.s,5);']);
end;


% Set the current figure as stored in the structure array
figure(s.pl.f)

if (mode==0)
    set(s.pl.e,'FaceColor','b');
    title([type ' model'],'Color','w','FontSize',24,'FontWeight','Bold')
else
    set(s.pl.e,'FaceVertexCData',s.p(:,mode))
    set(s.pl.e,'FaceColor','interp')
    title(sprintf('%s mode: %d Freq: %5.1f  Hz',type,mode,s.f(mode)),'Color','w','FontSize',24,'FontWeight','Bold')
end


